| pullCluster | R Documentation |
pullCluster sub-samples a spatially clustered qPLM
dataset (a qPLMclust object) and returns a qPLMtab object
with all the pixels in the selected cluster node.
pullCluster(qPLMclust)
qPLMclust |
A |
This function allows the user to sample an existing spatial clustering
scheme generated using qPLMClust. The display starts at the deepest split
in the cluster analysis, showing the two most dissimilar patches of pixels by
whichever criteria were chosen for qPLMClust. Advancing through the nodes by
entering f at the prompt shows additional splits in order of increasing
similarity. Once the desired set of splits is displayed, The user can then enter
s at the prompt to select one or more groups of pixels.
Other qPLM Analysis Functions:
angGaussSumm(),
centroidCorr(),
pullROI(),
pullqPLMSample(),
qPLMClust(),
qPLMTabulate()
#oldwd<-getwd()
#setwd(system.file("extdata", package = "microTransit"))
#load("testqPLMclust.R")
#setwd(oldwd)
testCluster<-pullCluster(testqPLMclust_arr)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.