View source: R/pullqPLMSample.R
| pullqPLMSample | R Documentation |
pullqPLMSample sub-samples a specified number of pixels
from a qPLMarr object in a square ROI around an interactively selected
point.
pullqPLMSample(qPLMarr, layer, pixels)
qPLMarr |
A |
layer |
Value from 1-3; this layer will be displayed on-screen for
selecting the ROI (1 = I, 2 = theta, 3 = phi).
The resulting subsample will include all of the 'stacked' layers from the
|
pixels |
approximate number of pixels required for the sample (rounding for a square region may pull pixels more than specified by this argument). |
A qPLMarr object with the subsampled pixels. This object will
maintain all the attributes of the original.
Other qPLM Analysis Functions:
angGaussSumm(),
centroidCorr(),
pullCluster(),
pullROI(),
qPLMClust(),
qPLMTabulate()
#oldwd<-getwd()
#setwd(system.file("extdata", package = "microTransit"))
#load("testqPLMarr.R")
#setwd(oldwd)
testSample<-pullqPLMSample(testqPLMarr)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.